@@ -104,7 +104,7 @@ class GIOBackend(duplicity.backend.Backend):
             # check for NOT_SUPPORTED because some schemas (e.g. file://) validly don't
             if e.code != Gio.IOErrorEnum.ALREADY_MOUNTED and e.code != Gio.IOErrorEnum.NOT_SUPPORTED:
                 log.FatalError(_("Connection failed, please check your password: %s")
-                               % str(e), log.ErrorCode.connection_failed)
+                               % util.uexc(e), log.ErrorCode.connection_failed)
         loop.quit()
 
     def handle_error(self, raise_error, e, op, file1=None, file2=None):
@@ -120,14 +120,14 @@ class GIOBackend(duplicity.backend.Backend):
                 code = log.ErrorCode.backend_no_space
         extra = ' '.join([util.escape(x) for x in [file1, file2] if x])
         extra = ' '.join([op, extra])
-        log.FatalError(str(e), code, extra)
+        log.FatalError(util.uexc(e), code, extra)
 
     def copy_progress(self, *args, **kwargs):
         pass
 
     @retry
     def copy_file(self, op, source, target, raise_errors=False):
-        log.Info(_("Writing %s") % target.get_parse_name())
+        log.Info(_("Writing %s") % util.ufn(target.get_parse_name()))
         try:
             source.copy(target,
                         Gio.FileCopyFlags.OVERWRITE | Gio.FileCopyFlags.NOFOLLOW_SYMLINKS,
