@@ -26,7 +26,7 @@ import socket
 
 
 # The current version of duplicity
-version = "0.6.24"
+version = "0.6.25"
 
 # Prefix for all files (appended before type-specific prefixes)
 file_prefix = ""
@@ -284,3 +284,6 @@ progress_rate = 3
 
 # Level of Redundancy in % for Par2 files
 par2_redundancy = 10
+
+# Verbatim par2 other options
+par2_options = ""
